[−][src]Enum exprz_core::parse::Error
Expression Parsing Error
Variants
Multiple expressions at top level
No closing quote
Group was not closed
Group was not opened
Found an empty group that was not opened or closed
Found leading whitespace
Found trailing symbols
Group was opened when only an Atom was expected
Atom was started when only a Group was expected